-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...

local L = addonTable.L

-- constants
local tx_indicator_green  = "Interface\\Common\\Indicator-Green"
local tx_indicator_red    = "Interface\\Common\\Indicator-Red"

-- lists customization interface
local constructors = DailyGlobalCheck.Constructors
local editframe = DailyGlobalCheck.EditPanel
local lists = DailyGlobalCheck.ListFunctions
local help = DailyGlobalCheck.HelpFunctions

local f_lists, f_preview, f_quests, editframe_list

local HelpPlate = {
	FramePos = { x = 0, y = -80 },
	FrameSize = { width = 700, height = 720 },
	[1] = { ButtonPos = { x = 240, y = 5 },  HighLightBox = { x = 10, y = 0, width = 285, height = 39 },	 ToolTipDir = "RIGHT",  ToolTipText = L["help_edt_1"] },
	[2] = { ButtonPos = { x = 125, y = -300 }, HighLightBox = { x = 10, y = -41, width = 245, height = 660 },  ToolTipDir = "DOWN",   ToolTipText = L["help_edt_2"] },
	[3] = { ButtonPos = { x = 253, y = -300 }, HighLightBox = { x = 260, y = -41, width = 35, height = 660 }, ToolTipDir = "DOWN",   ToolTipText = L["help_edt_3"] },
	[4] = { ButtonPos = { x = 450, y = -300},  HighLightBox = { x = 320, y = 0, width = 375, height = 700 },  ToolTipDir = "DOWN",		ToolTipText = L["help_edt_4"] },
	[5] = { ButtonPos = { x = 600, y = -630 },  HighLightBox = { x = 550, y = -630, width = 80, height = 40 },  ToolTipDir = "RIGHT",  ToolTipText = L["help_edt_5"] },
}
	
local function ToggleTutorial()
 if not help:isShowing(HelpPlate) then
  help:Show(HelpPlate, editframe, DGC_EFHelpButton)
 else
  help:Hide()
 end
end

local function ListBtn_CLick(arg)
 local offset = HybridScrollFrame_GetOffset(f_lists)
 local title = f_lists.selected and f_lists.buttons[f_lists.selected - offset].name:GetText()

 local function checkselected(title)
  local sel = DailyGlobalCheck:GetSelectedList()
  if not sel or (sel and sel["Title"] == title and not lists:Find(title, true)) then
   DailyGlobalCheck:OpenList(lists:FindFirst(true))
  end
 end

 if arg == "add" then
  if table.getn(DGC_CustomLists.Lists) >= addonTable.maxlists then
   print(string.format(L["lists_limit"], addonTable.maxlists))
   return
  end
 
  local list = lists:New()
  table.insert(DGC_CustomLists.Lists, list)
  local index = #DGC_CustomLists.Lists
  DGC_CustomLists.Lists[index or #DGC_CustomLists.Lists + 1] = list
  lists:setActive(list, true)
  DailyGlobalCheck:OpenList(list)
  editframe:Update()
  DGC_Mainframe:RefreshListButtons()
 elseif arg == "mod" then
  if not title or lists:isPlugin(title) then return end -- can't edit fixed plugins
 
  local _, list = lists:Find(title, false)
  if not lists:isList(list) then return end

  editframe:EditList(list)
  editframe:Hide()
  editframe_list:Show()
 elseif arg == "del" then
  if not title or lists:isPlugin(title) then return end -- can't remove fixed plugins

  lists:Remove(title)
  editframe:Update()
  checkselected(title)
  DGC_Mainframe:RefreshListButtons()
 elseif arg == "toggle" then
  if not title then return end
  
  local _, list = lists:Find(title, false)
  lists:setActive(list, not lists:isActive(list))  
  DailyGlobalCheck:OpenList(list)
  editframe:Update()
  checkselected(title)
  DGC_Mainframe:RefreshListButtons()
 end
end

local function sfListsUpdate(self)
 local height = 20 -- height of a row
 local offset = HybridScrollFrame_GetOffset(self)
 local buttons = self.buttons

 local list = DailyGlobalCheck.Lists -- plugin lists
 local list_length = #(DailyGlobalCheck.Lists)
 local total_length = lists:Count()
 local off = 0

 for i=1, #buttons do
  local index = offset + i
  if index > list_length then
   list = DGC_CustomLists.Lists
   off = list_length
  end
  if index <= total_length then
   if index == self.selected then
    buttons[i]:LockHighlight()
   else
    buttons[i]:UnlockHighlight()
   end
   buttons[i].icon:SetTexture(list[index - off].Icon)
   if lists:isActive(list[index - off]) then
    buttons[i].icon2:SetTexture(tx_indicator_green)
   else
    buttons[i].icon2:SetTexture(tx_indicator_red)
   end
   buttons[i].name:SetText(list[index - off].Title)
   buttons[i]:Show()
  else
   buttons[i]:Hide()
  end
  HybridScrollFrame_Update(self, height * total_length, height)
 end
end

local function sfListsBtnClick(self, button)
 if not f_lists.selected then return end
 local sel = f_lists.selected - HybridScrollFrame_GetOffset(f_lists)
 if sel == self.index then
  ListBtn_CLick("toggle")
 end
end

function editframe:Initialize()
 if not DGC_Mainframe then constructors:MainFrame() end
 
 -------------------
 -- Lists listbox --
 local f = constructors:ListBox(editframe, "DGC_EFListsScrollFrame", 280, 650, "DGCListButtonTemplate", sfListsUpdate, sfListsBtnClick)
 f:SetPoint("TOPLEFT", editframe, "TOPLEFT", 20, -120)
 f:SetPoint("BOTTOMLEFT", editframe, "BOTTOMLEFT", 20, 20)
 f:SetView("Lists")
 f_lists = f

 -------------------
 -- Preview Frame --
 f_preview = DGC_Mainframe

 -- Create List
 f = constructors:CreateListButton(editframe, "DGC_EFAddListBtn")
 f:SetText(CALENDAR_CREATE)
 f:SetSize(53, 25)
 f:SetPoint("TOPLEFT", f_lists, "TOPLEFT", 0, 30)
 f.clickfunc = function() ListBtn_CLick("add") end

 -- Edit List
 f = constructors:CreateListButton(editframe, "DGC_EFModListBtn")
 f:SetText(EDIT)
 f:SetSize(53, 25)
 f:SetPoint("LEFT", DGC_EFAddListBtn, "RIGHT", 5, 0)
  f.clickfunc = function() ListBtn_CLick("mod") end

 -- Delete List
 f = constructors:CreateListButton(editframe, "DGC_EFDelListBtn")
 f:SetText(REMOVE)
 f:SetSize(53, 25)
 f:SetPoint("LEFT", DGC_EFModListBtn, "RIGHT", 5, 0)
 f.clickfunc = function() ListBtn_CLick("del") end

 -- Toggle List
 f = constructors:CreateListButton(editframe, "DGC_EFToggleListBtn")
 f:SetText("Toggle")
 f:SetSize(53, 25)
 f:SetPoint("LEFT", DGC_EFDelListBtn, "RIGHT", 5, 0)
 f.clickfunc = function() ListBtn_CLick("toggle") end
 
 editframe_list = editframe:CreateListEditFrame()
 editframe_list:SetPoint("CENTER")
 editframe.ListPanel = editframe_list
 
 --[[
 editframe.title = editframe:CreateFontString()
 editframe.title:SetFont("Fonts\\FRIZQT__.TTF", 18)
 editframe.title:SetText("DGC Edit Panel")
 editframe.title:SetPoint("TOP", editframe, "TOP", 0, -20)
 ]]
 
 editframe:SetScript("OnShow", function()
  DGC_Mainframe:LockInEditFrame()
  addonTable.refresh()
  DGC_Mainframe:RefreshListButtons()
 end)
 editframe:SetScript("OnHide", function() help:Hide() end)

 -- Close Button
 f = constructors:CreateListButton(editframe)
 f:SetText("X")
 f:SetSize(30, 30)
 f:SetPoint("TOPRIGHT")
 f.clickfunc = DGC_Mainframe.closebtn.clickfunc
 editframe.btnclose = f
 
 -- Help Button
 f = CreateFrame("Button", "DGC_EFHelpButton", editframe, "MainHelpPlateButton")
 f:SetPoint("TOPLEFT")
 f:SetScript("OnClick", function()
  ToggleTutorial()
 end)
 
 editframe:SetPoint("CENTER")
 editframe:Hide()
 editframe.initialized = true
end

function editframe.Activate(self)
 if not self.initialized then self:Initialize() end
 self:Show()
 self.active = true
 f_preview.btnedit.tex:SetVertexColor(0,1,0,1)
 if editframe_list then
  editframe_list:Hide()
 end
end
 
function editframe.Deactivate(self)
 self:Hide()
 if f_preview then 
  f_preview:Unlock()
  f_preview.btnedit.tex:SetVertexColor(1,1,1,1)
 end
 if editframe_list then
  editframe_list:Hide()
 end
 self.active = false
end

function editframe:Update()
 if f_lists then f_lists:update() end
end